@@ -2,7 +2,8 @@ use 5.14.0;
 
 package Map::Metro::Plugin::Map::Athens;
 
-our $VERSION = '0.1100'; # VERSION
+our $VERSION = '0.1101'; # VERSION
+# ABSTRACT: Map::Metro map for Athens
 
 use Moose;
 with 'Map::Metro::Plugin::Map';
@@ -21,17 +22,27 @@ sub map_package {
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
 Map::Metro::Plugin::Map::Athens - Map::Metro map for Athens
 
+=head1 VERSION
+
+Version 0.1101, released 2015-01-26.
+
 =head1 SYNOPSIS
 
     use Map::Metro;
     my $graph = Map::Metro->new('Athens')->parse;
 
+Or:
+
+    $ map-metro.pl route Athens Marousi Panormou
+
 =head1 DESCRIPTION
 
 See L<Map::Metro> for usage information.
@@ -48,23 +59,25 @@ Notes:
 
 See L<Map::Metro::Plugin::Map::Athens::Lines>.
 
-=begin HTML
+=for HTML <p><a href="https://raw.githubusercontent.com/Csson/p5-Map-Metro-Athens/master/static/images/athens.png"><img src="https://raw.githubusercontent.com/Csson/p5-Map-Metro-Athens/master/static/images/athens.png" style="max-width: 600px" /></a></p>
 
-<p><a href="https://raw.githubusercontent.com/Csson/p5-Map-Metro-Athens/master/static/images/athens.png"><img src="https://raw.githubusercontent.com/Csson/p5-Map-Metro-Athens/master/static/images/athens.png" style="max-width: 600px" /></a></p>
+=head1 SOURCE
 
-=end HTML
+Source repository is at L<https://github.com/Csson/p5-Map-Metro-Athens>.
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Map-Metro-Plugin-Map-Athens>.
 
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
